/* -*- buffer-read-only: t -*-
 *
 *    keywords.h
 *
 *    Copyright (C) 1994, 1995, 1996, 1997, 1999, 2000, 2001, 2002, 2005,
 *    2006, 2007 by Larry Wall and others
 *
 *    You may distribute under the terms of either the GNU General Public
 *    License or the Artistic License, as specified in the README file.
 *
 * !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
 * This file is built by regen/keywords.pl from its data.
 * Any changes made here will be lost!
 */

#define KEY_NULL		0
#define KEY___FILE__		1
#define KEY___LINE__		2
#define KEY___PACKAGE__		3
#define KEY___DATA__		4
#define KEY___END__		5
#define KEY___SUB__		6
#define KEY_AUTOLOAD		7
#define KEY_BEGIN		8
#define KEY_UNITCHECK		9
#define KEY_DESTROY		10
#define KEY_END			11
#define KEY_INIT		12
#define KEY_CHECK		13
#define KEY_abs			14
#define KEY_accept		15
#define KEY_alarm		16
#define KEY_and			17
#define KEY_atan2		18
#define KEY_bind		19
#define KEY_binmode		20
#define KEY_bless		21
#define KEY_break		22
#define KEY_caller		23
#define KEY_catch		24
#define KEY_chdir		25
#define KEY_chmod		26
#define KEY_chomp		27
#define KEY_chop		28
#define KEY_chown		29
#define KEY_chr			30
#define KEY_chroot		31
#define KEY_close		32
#define KEY_closedir		33
#define KEY_cmp			34
#define KEY_connect		35
#define KEY_continue		36
#define KEY_cos			37
#define KEY_crypt		38
#define KEY_dbmclose		39
#define KEY_dbmopen		40
#define KEY_default		41
#define KEY_defer		42
#define KEY_defined		43
#define KEY_delete		44
#define KEY_die			45
#define KEY_do			46
#define KEY_dump		47
#define KEY_each		48
#define KEY_else		49
#define KEY_elsif		50
#define KEY_endgrent		51
#define KEY_endhostent		52
#define KEY_endnetent		53
#define KEY_endprotoent		54
#define KEY_endpwent		55
#define KEY_endservent		56
#define KEY_eof			57
#define KEY_eq			58
#define KEY_eval		59
#define KEY_evalbytes		60
#define KEY_exec		61
#define KEY_exists		62
#define KEY_exit		63
#define KEY_exp			64
#define KEY_fc			65
#define KEY_fcntl		66
#define KEY_fileno		67
#define KEY_finally		68
#define KEY_flock		69
#define KEY_for			70
#define KEY_foreach		71
#define KEY_fork		72
#define KEY_format		73
#define KEY_formline		74
#define KEY_ge			75
#define KEY_getc		76
#define KEY_getgrent		77
#define KEY_getgrgid		78
#define KEY_getgrnam		79
#define KEY_gethostbyaddr	80
#define KEY_gethostbyname	81
#define KEY_gethostent		82
#define KEY_getlogin		83
#define KEY_getnetbyaddr	84
#define KEY_getnetbyname	85
#define KEY_getnetent		86
#define KEY_getpeername		87
#define KEY_getpgrp		88
#define KEY_getppid		89
#define KEY_getpriority		90
#define KEY_getprotobyname	91
#define KEY_getprotobynumber	92
#define KEY_getprotoent		93
#define KEY_getpwent		94
#define KEY_getpwnam		95
#define KEY_getpwuid		96
#define KEY_getservbyname	97
#define KEY_getservbyport	98
#define KEY_getservent		99
#define KEY_getsockname		100
#define KEY_getsockopt		101
#define KEY_given		102
#define KEY_glob		103
#define KEY_gmtime		104
#define KEY_goto		105
#define KEY_grep		106
#define KEY_gt			107
#define KEY_hex			108
#define KEY_if			109
#define KEY_index		110
#define KEY_int			111
#define KEY_ioctl		112
#define KEY_isa			113
#define KEY_join		114
#define KEY_keys		115
#define KEY_kill		116
#define KEY_last		117
#define KEY_lc			118
#define KEY_lcfirst		119
#define KEY_le			120
#define KEY_length		121
#define KEY_link		122
#define KEY_listen		123
#define KEY_local		124
#define KEY_localtime		125
#define KEY_lock		126
#define KEY_log			127
#define KEY_lstat		128
#define KEY_lt			129
#define KEY_m			130
#define KEY_map			131
#define KEY_mkdir		132
#define KEY_msgctl		133
#define KEY_msgget		134
#define KEY_msgrcv		135
#define KEY_msgsnd		136
#define KEY_my			137
#define KEY_ne			138
#define KEY_next		139
#define KEY_no			140
#define KEY_not			141
#define KEY_oct			142
#define KEY_open		143
#define KEY_opendir		144
#define KEY_or			145
#define KEY_ord			146
#define KEY_our			147
#define KEY_pack		148
#define KEY_package		149
#define KEY_pipe		150
#define KEY_pop			151
#define KEY_pos			152
#define KEY_print		153
#define KEY_printf		154
#define KEY_prototype		155
#define KEY_push		156
#define KEY_q			157
#define KEY_qq			158
#define KEY_qr			159
#define KEY_quotemeta		160
#define KEY_qw			161
#define KEY_qx			162
#define KEY_rand		163
#define KEY_read		164
#define KEY_readdir		165
#define KEY_readline		166
#define KEY_readlink		167
#define KEY_readpipe		168
#define KEY_recv		169
#define KEY_redo		170
#define KEY_ref			171
#define KEY_rename		172
#define KEY_require		173
#define KEY_reset		174
#define KEY_return		175
#define KEY_reverse		176
#define KEY_rewinddir		177
#define KEY_rindex		178
#define KEY_rmdir		179
#define KEY_s			180
#define KEY_say			181
#define KEY_scalar		182
#define KEY_seek		183
#define KEY_seekdir		184
#define KEY_select		185
#define KEY_semctl		186
#define KEY_semget		187
#define KEY_semop		188
#define KEY_send		189
#define KEY_setgrent		190
#define KEY_sethostent		191
#define KEY_setnetent		192
#define KEY_setpgrp		193
#define KEY_setpriority		194
#define KEY_setprotoent		195
#define KEY_setpwent		196
#define KEY_setservent		197
#define KEY_setsockopt		198
#define KEY_shift		199
#define KEY_shmctl		200
#define KEY_shmget		201
#define KEY_shmread		202
#define KEY_shmwrite		203
#define KEY_shutdown		204
#define KEY_sin			205
#define KEY_sleep		206
#define KEY_socket		207
#define KEY_socketpair		208
#define KEY_sort		209
#define KEY_splice		210
#define KEY_split		211
#define KEY_sprintf		212
#define KEY_sqrt		213
#define KEY_srand		214
#define KEY_stat		215
#define KEY_state		216
#define KEY_study		217
#define KEY_sub			218
#define KEY_substr		219
#define KEY_symlink		220
#define KEY_syscall		221
#define KEY_sysopen		222
#define KEY_sysread		223
#define KEY_sysseek		224
#define KEY_system		225
#define KEY_syswrite		226
#define KEY_tell		227
#define KEY_telldir		228
#define KEY_tie			229
#define KEY_tied		230
#define KEY_time		231
#define KEY_times		232
#define KEY_tr			233
#define KEY_try			234
#define KEY_truncate		235
#define KEY_uc			236
#define KEY_ucfirst		237
#define KEY_umask		238
#define KEY_undef		239
#define KEY_unless		240
#define KEY_unlink		241
#define KEY_unpack		242
#define KEY_unshift		243
#define KEY_untie		244
#define KEY_until		245
#define KEY_use			246
#define KEY_utime		247
#define KEY_values		248
#define KEY_vec			249
#define KEY_wait		250
#define KEY_waitpid		251
#define KEY_wantarray		252
#define KEY_warn		253
#define KEY_when		254
#define KEY_while		255
#define KEY_write		256
#define KEY_x			257
#define KEY_xor			258
#define KEY_y			259

/* Generated from:
 * b680fb3a27b173b65d9c4e534ad92897c925e336476879a6be1da18ac55cbe8b regen/keywords.pl
 * ex: set ro: */
