# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'To_PerlLB'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'To_PerlLB'}{'missing'} = 'Alphabetic';

return <<'END';
0	8	Combining_Mark
9		Break_After
A		Line_Feed
B	C	Mandatory_Break
D		Carriage_Return
E	1F	Combining_Mark
20		Space
21		Exclamation
22		Quotation
24		Prefix_Numeric
25		Postfix_Numeric
27		Quotation
28		Open_Punctuation
29		Close_Parenthesis
2B		Prefix_Numeric
2C		Infix_Numeric
2D		Hyphen
2E		Infix_Numeric
2F		Break_Symbols
30	39	Numeric
3A	3B	Infix_Numeric
3F		Exclamation
5B		Open_Punctuation
5C		Prefix_Numeric
5D		Close_Parenthesis
7B		Open_Punctuation
7C		Break_After
7D		Close_Punctuation
7F	84	Combining_Mark
85		Next_Line
86	9F	Combining_Mark
A0		Glue
A1		Open_Punctuation
A2		Postfix_Numeric
A3	A5	Prefix_Numeric
AB		Quotation
AD		Break_After
B0		Postfix_Numeric
B1		Prefix_Numeric
B4		Break_Before
BB		Quotation
BF		Open_Punctuation
2C8		Break_Before
2CC		Break_Before
2DF		Break_Before
300	34E	Combining_Mark
34F		Glue
350	35B	Combining_Mark
35C	362	Glue
363	36F	Combining_Mark
37E		Infix_Numeric
483	489	Combining_Mark
589		Infix_Numeric
58A		Break_After
58F		Prefix_Numeric
591	5BD	Combining_Mark
5BE		Break_After
5BF		Combining_Mark
5C1	5C2	Combining_Mark
5C4	5C5	Combining_Mark
5C6		Exclamation
5C7		Combining_Mark
5D0	5EA	Hebrew_Letter
5EF	5F2	Hebrew_Letter
609	60B	Postfix_Numeric
60C	60D	Infix_Numeric
610	61A	Combining_Mark
61B		Exclamation
61C		Combining_Mark
61D	61F	Exclamation
64B	65F	Combining_Mark
660	669	Numeric
66A		Postfix_Numeric
66B	66C	Numeric
670		Combining_Mark
6D4		Exclamation
6D6	6DC	Combining_Mark
6DF	6E4	Combining_Mark
6E7	6E8	Combining_Mark
6EA	6ED	Combining_Mark
6F0	6F9	Numeric
711		Combining_Mark
730	74A	Combining_Mark
7A6	7B0	Combining_Mark
7C0	7C9	Numeric
7EB	7F3	Combining_Mark
7F8		Infix_Numeric
7F9		Exclamation
7FD		Combining_Mark
7FE	7FF	Prefix_Numeric
816	819	Combining_Mark
81B	823	Combining_Mark
825	827	Combining_Mark
829	82D	Combining_Mark
859	85B	Combining_Mark
898	89F	Combining_Mark
8CA	8E1	Combining_Mark
8E3	903	Combining_Mark
93A	93C	Combining_Mark
93E	94F	Combining_Mark
951	957	Combining_Mark
962	963	Combining_Mark
964	965	Break_After
966	96F	Numeric
981	983	Combining_Mark
9BC		Combining_Mark
9BE	9C4	Combining_Mark
9C7	9C8	Combining_Mark
9CB	9CD	Combining_Mark
9D7		Combining_Mark
9E2	9E3	Combining_Mark
9E6	9EF	Numeric
9F2	9F3	Postfix_Numeric
9F9		Postfix_Numeric
9FB		Prefix_Numeric
9FE		Combining_Mark
A01	A03	Combining_Mark
A3C		Combining_Mark
A3E	A42	Combining_Mark
A47	A48	Combining_Mark
A4B	A4D	Combining_Mark
A51		Combining_Mark
A66	A6F	Numeric
A70	A71	Combining_Mark
A75		Combining_Mark
A81	A83	Combining_Mark
ABC		Combining_Mark
ABE	AC5	Combining_Mark
AC7	AC9	Combining_Mark
ACB	ACD	Combining_Mark
AE2	AE3	Combining_Mark
AE6	AEF	Numeric
AF1		Prefix_Numeric
AFA	AFF	Combining_Mark
B01	B03	Combining_Mark
B3C		Combining_Mark
B3E	B44	Combining_Mark
B47	B48	Combining_Mark
B4B	B4D	Combining_Mark
B55	B57	Combining_Mark
B62	B63	Combining_Mark
B66	B6F	Numeric
B82		Combining_Mark
BBE	BC2	Combining_Mark
BC6	BC8	Combining_Mark
BCA	BCD	Combining_Mark
BD7		Combining_Mark
BE6	BEF	Numeric
BF9		Prefix_Numeric
C00	C04	Combining_Mark
C3C		Combining_Mark
C3E	C44	Combining_Mark
C46	C48	Combining_Mark
C4A	C4D	Combining_Mark
C55	C56	Combining_Mark
C62	C63	Combining_Mark
C66	C6F	Numeric
C77		Break_Before
C81	C83	Combining_Mark
C84		Break_Before
CBC		Combining_Mark
CBE	CC4	Combining_Mark
CC6	CC8	Combining_Mark
CCA	CCD	Combining_Mark
CD5	CD6	Combining_Mark
CE2	CE3	Combining_Mark
CE6	CEF	Numeric
D00	D03	Combining_Mark
D3B	D3C	Combining_Mark
D3E	D44	Combining_Mark
D46	D48	Combining_Mark
D4A	D4D	Combining_Mark
D57		Combining_Mark
D62	D63	Combining_Mark
D66	D6F	Numeric
D79		Postfix_Numeric
D81	D83	Combining_Mark
DCA		Combining_Mark
DCF	DD4	Combining_Mark
DD6		Combining_Mark
DD8	DDF	Combining_Mark
DE6	DEF	Numeric
DF2	DF3	Combining_Mark
E31		Combining_Mark
E34	E3A	Combining_Mark
E3F		Prefix_Numeric
E47	E4E	Combining_Mark
E50	E59	Numeric
E5A	E5B	Break_After
EB1		Combining_Mark
EB4	EBC	Combining_Mark
EC8	ECD	Combining_Mark
ED0	ED9	Numeric
F01	F04	Break_Before
F06	F07	Break_Before
F08		Glue
F09	F0A	Break_Before
F0B		Break_After
F0C		Glue
F0D	F11	Exclamation
F12		Glue
F14		Exclamation
F18	F19	Combining_Mark
F20	F29	Numeric
F34		Break_After
F35		Combining_Mark
F37		Combining_Mark
F39		Combining_Mark
F3A		Open_Punctuation
F3B		Close_Punctuation
F3C		Open_Punctuation
F3D		Close_Punctuation
F3E	F3F	Combining_Mark
F71	F7E	Combining_Mark
F7F		Break_After
F80	F84	Combining_Mark
F85		Break_After
F86	F87	Combining_Mark
F8D	F97	Combining_Mark
F99	FBC	Combining_Mark
FBE	FBF	Break_After
FC6		Combining_Mark
FD0	FD1	Break_Before
FD2		Break_After
FD3		Break_Before
FD9	FDA	Glue
102B	103E	Combining_Mark
1040	1049	Numeric
104A	104B	Break_After
1056	1059	Combining_Mark
105E	1060	Combining_Mark
1062	1064	Combining_Mark
1067	106D	Combining_Mark
1071	1074	Combining_Mark
1082	108D	Combining_Mark
108F		Combining_Mark
1090	1099	Numeric
109A	109D	Combining_Mark
1100	115F	JL
1160	11A7	JV
11A8	11FF	JT
135D	135F	Combining_Mark
1361		Break_After
1400		Break_After
1680		Break_After
169B		Open_Punctuation
169C		Close_Punctuation
16EB	16ED	Break_After
1712	1715	Combining_Mark
1732	1734	Combining_Mark
1735	1736	Break_After
1752	1753	Combining_Mark
1772	1773	Combining_Mark
17B4	17D3	Combining_Mark
17D4	17D5	Break_After
17D6		Nonstarter
17D8		Break_After
17DA		Break_After
17DB		Prefix_Numeric
17DD		Combining_Mark
17E0	17E9	Numeric
1802	1803	Exclamation
1804	1805	Break_After
1806		Break_Before
1808	1809	Exclamation
180B	180D	Combining_Mark
180E		Glue
180F		Combining_Mark
1810	1819	Numeric
1885	1886	Combining_Mark
18A9		Combining_Mark
1920	192B	Combining_Mark
1930	193B	Combining_Mark
1944	1945	Exclamation
1946	194F	Numeric
19D0	19D9	Numeric
1A17	1A1B	Combining_Mark
1A55	1A5E	Combining_Mark
1A60	1A7C	Combining_Mark
1A7F		Combining_Mark
1A80	1A89	Numeric
1A90	1A99	Numeric
1AB0	1ACE	Combining_Mark
1B00	1B04	Combining_Mark
1B34	1B44	Combining_Mark
1B50	1B59	Numeric
1B5A	1B5B	Break_After
1B5D	1B60	Break_After
1B6B	1B73	Combining_Mark
1B7D	1B7E	Break_After
1B80	1B82	Combining_Mark
1BA1	1BAD	Combining_Mark
1BB0	1BB9	Numeric
1BE6	1BF3	Combining_Mark
1C24	1C37	Combining_Mark
1C3B	1C3F	Break_After
1C40	1C49	Numeric
1C50	1C59	Numeric
1C7E	1C7F	Break_After
1CD0	1CD2	Combining_Mark
1CD4	1CE8	Combining_Mark
1CED		Combining_Mark
1CF4		Combining_Mark
1CF7	1CF9	Combining_Mark
1DC0	1DFF	Combining_Mark
1FFD		Break_Before
2000	2006	Break_After
2007		Glue
2008	200A	Break_After
200B		ZWSpace
200C		Combining_Mark
200D		ZWJ
200E	200F	Combining_Mark
2010		Break_After
2011		Glue
2012	2013	Break_After
2014		Break_Both
2018	2019	Quotation
201A		Open_Punctuation
201B	201D	Quotation
201E		Open_Punctuation
201F		Quotation
2024	2026	Inseparable
2027		Break_After
2028	2029	Mandatory_Break
202A	202E	Combining_Mark
202F		Glue
2030	2037	Postfix_Numeric
2039	203A	Quotation
203C	203D	Nonstarter
2044		Infix_Numeric
2045		Open_Punctuation
2046		Close_Punctuation
2047	2049	Nonstarter
2056		Break_After
2058	205B	Break_After
205D	205F	Break_After
2060		Word_Joiner
2066	206F	Combining_Mark
207D		Open_Punctuation
207E		Close_Punctuation
208D		Open_Punctuation
208E		Close_Punctuation
20A0	20A6	Prefix_Numeric
20A7		Postfix_Numeric
20A8	20B5	Prefix_Numeric
20B6		Postfix_Numeric
20B7	20BA	Prefix_Numeric
20BB		Postfix_Numeric
20BC	20BD	Prefix_Numeric
20BE		Postfix_Numeric
20BF		Prefix_Numeric
20C0		Postfix_Numeric
20C1	20CF	Prefix_Numeric
20D0	20F0	Combining_Mark
2103		Postfix_Numeric
2109		Postfix_Numeric
2116		Prefix_Numeric
2212	2213	Prefix_Numeric
22EF		Inseparable
2308		Open_Punctuation
2309		Close_Punctuation
230A		Open_Punctuation
230B		Close_Punctuation
231A	231B	Ideographic
2329		East_Asian_OP
232A		Close_Punctuation
23F0	23F3	Ideographic
2600	2603	Ideographic
2614	2615	Ideographic
2618		Ideographic
261A	261C	Ideographic
261D		E_Base
261E	261F	Ideographic
2639	263B	Ideographic
2668		Ideographic
267F		Ideographic
26BD	26C8	Ideographic
26CD		Ideographic
26CF	26D1	Ideographic
26D3	26D4	Ideographic
26D8	26D9	Ideographic
26DC		Ideographic
26DF	26E1	Ideographic
26EA		Ideographic
26F1	26F5	Ideographic
26F7	26F8	Ideographic
26F9		E_Base
26FA		Ideographic
26FD	2704	Ideographic
2708	2709	Ideographic
270A	270D	E_Base
275B	2760	Quotation
2762	2763	Exclamation
2764		Ideographic
2768		Open_Punctuation
2769		Close_Punctuation
276A		Open_Punctuation
276B		Close_Punctuation
276C		Open_Punctuation
276D		Close_Punctuation
276E		Open_Punctuation
276F		Close_Punctuation
2770		Open_Punctuation
2771		Close_Punctuation
2772		Open_Punctuation
2773		Close_Punctuation
2774		Open_Punctuation
2775		Close_Punctuation
27C5		Open_Punctuation
27C6		Close_Punctuation
27E6		Open_Punctuation
27E7		Close_Punctuation
27E8		Open_Punctuation
27E9		Close_Punctuation
27EA		Open_Punctuation
27EB		Close_Punctuation
27EC		Open_Punctuation
27ED		Close_Punctuation
27EE		Open_Punctuation
27EF		Close_Punctuation
2983		Open_Punctuation
2984		Close_Punctuation
2985		Open_Punctuation
2986		Close_Punctuation
2987		Open_Punctuation
2988		Close_Punctuation
2989		Open_Punctuation
298A		Close_Punctuation
298B		Open_Punctuation
298C		Close_Punctuation
298D		Open_Punctuation
298E		Close_Punctuation
298F		Open_Punctuation
2990		Close_Punctuation
2991		Open_Punctuation
2992		Close_Punctuation
2993		Open_Punctuation
2994		Close_Punctuation
2995		Open_Punctuation
2996		Close_Punctuation
2997		Open_Punctuation
2998		Close_Punctuation
29D8		Open_Punctuation
29D9		Close_Punctuation
29DA		Open_Punctuation
29DB		Close_Punctuation
29FC		Open_Punctuation
29FD		Close_Punctuation
2CEF	2CF1	Combining_Mark
2CF9		Exclamation
2CFA	2CFC	Break_After
2CFE		Exclamation
2CFF		Break_After
2D70		Break_After
2D7F		Combining_Mark
2DE0	2DFF	Combining_Mark
2E00	2E0D	Quotation
2E0E	2E15	Break_After
2E17		Break_After
2E18		Open_Punctuation
2E19		Break_After
2E1C	2E1D	Quotation
2E20	2E21	Quotation
2E22		Open_Punctuation
2E23		Close_Punctuation
2E24		Open_Punctuation
2E25		Close_Punctuation
2E26		Open_Punctuation
2E27		Close_Punctuation
2E28		Open_Punctuation
2E29		Close_Punctuation
2E2A	2E2D	Break_After
2E2E		Exclamation
2E30	2E31	Break_After
2E33	2E34	Break_After
2E3A	2E3B	Break_Both
2E3C	2E3E	Break_After
2E40	2E41	Break_After
2E42		Open_Punctuation
2E43	2E4A	Break_After
2E4C		Break_After
2E4E	2E4F	Break_After
2E53	2E54	Exclamation
2E55		Open_Punctuation
2E56		Close_Punctuation
2E57		Open_Punctuation
2E58		Close_Punctuation
2E59		Open_Punctuation
2E5A		Close_Punctuation
2E5B		Open_Punctuation
2E5C		Close_Punctuation
2E5D		Break_After
2E80	2E99	Ideographic
2E9B	2EF3	Ideographic
2F00	2FD5	Ideographic
2FF0	2FFB	Ideographic
3000		Break_After
3001	3002	Close_Punctuation
3003	3004	Ideographic
3005		Nonstarter
3006	3007	Ideographic
3008		East_Asian_OP
3009		Close_Punctuation
300A		East_Asian_OP
300B		Close_Punctuation
300C		East_Asian_OP
300D		Close_Punctuation
300E		East_Asian_OP
300F		Close_Punctuation
3010		East_Asian_OP
3011		Close_Punctuation
3012	3013	Ideographic
3014		East_Asian_OP
3015		Close_Punctuation
3016		East_Asian_OP
3017		Close_Punctuation
3018		East_Asian_OP
3019		Close_Punctuation
301A		East_Asian_OP
301B		Close_Punctuation
301C		Nonstarter
301D		East_Asian_OP
301E	301F	Close_Punctuation
3020	3029	Ideographic
302A	302F	Combining_Mark
3030	3034	Ideographic
3035		Combining_Mark
3036	303A	Ideographic
303B	303C	Nonstarter
303D	303F	Ideographic
3041		Nonstarter
3042		Ideographic
3043		Nonstarter
3044		Ideographic
3045		Nonstarter
3046		Ideographic
3047		Nonstarter
3048		Ideographic
3049		Nonstarter
304A	3062	Ideographic
3063		Nonstarter
3064	3082	Ideographic
3083		Nonstarter
3084		Ideographic
3085		Nonstarter
3086		Ideographic
3087		Nonstarter
3088	308D	Ideographic
308E		Nonstarter
308F	3094	Ideographic
3095	3096	Nonstarter
3099	309A	Combining_Mark
309B	309E	Nonstarter
309F		Ideographic
30A0	30A1	Nonstarter
30A2		Ideographic
30A3		Nonstarter
30A4		Ideographic
30A5		Nonstarter
30A6		Ideographic
30A7		Nonstarter
30A8		Ideographic
30A9		Nonstarter
30AA	30C2	Ideographic
30C3		Nonstarter
30C4	30E2	Ideographic
30E3		Nonstarter
30E4		Ideographic
30E5		Nonstarter
30E6		Ideographic
30E7		Nonstarter
30E8	30ED	Ideographic
30EE		Nonstarter
30EF	30F4	Ideographic
30F5	30F6	Nonstarter
30F7	30FA	Ideographic
30FB	30FE	Nonstarter
30FF		Ideographic
3105	312F	Ideographic
3131	318E	Ideographic
3190	31E3	Ideographic
31F0	31FF	Nonstarter
3200	321E	Ideographic
3220	3247	Ideographic
3250	4DBF	Ideographic
4E00	A014	Ideographic
A015		Nonstarter
A016	A48C	Ideographic
A490	A4C6	Ideographic
A4FE	A4FF	Break_After
A60D		Break_After
A60E		Exclamation
A60F		Break_After
A620	A629	Numeric
A66F	A672	Combining_Mark
A674	A67D	Combining_Mark
A69E	A69F	Combining_Mark
A6F0	A6F1	Combining_Mark
A6F3	A6F7	Break_After
A802		Combining_Mark
A806		Combining_Mark
A80B		Combining_Mark
A823	A827	Combining_Mark
A82C		Combining_Mark
A838		Postfix_Numeric
A874	A875	Break_Before
A876	A877	Exclamation
A880	A881	Combining_Mark
A8B4	A8C5	Combining_Mark
A8CE	A8CF	Break_After
A8D0	A8D9	Numeric
A8E0	A8F1	Combining_Mark
A8FC		Break_Before
A8FF		Combining_Mark
A900	A909	Numeric
A926	A92D	Combining_Mark
A92E	A92F	Break_After
A947	A953	Combining_Mark
A960	A97C	JL
A980	A983	Combining_Mark
A9B3	A9C0	Combining_Mark
A9C7	A9C9	Break_After
A9D0	A9D9	Numeric
A9E5		Combining_Mark
A9F0	A9F9	Numeric
AA29	AA36	Combining_Mark
AA43		Combining_Mark
AA4C	AA4D	Combining_Mark
AA50	AA59	Numeric
AA5D	AA5F	Break_After
AA7B	AA7D	Combining_Mark
AAB0		Combining_Mark
AAB2	AAB4	Combining_Mark
AAB7	AAB8	Combining_Mark
AABE	AABF	Combining_Mark
AAC1		Combining_Mark
AAEB	AAEF	Combining_Mark
AAF0	AAF1	Break_After
AAF5	AAF6	Combining_Mark
ABE3	ABEA	Combining_Mark
ABEB		Break_After
ABEC	ABED	Combining_Mark
ABF0	ABF9	Numeric
AC00		H2
AC01	AC1B	H3
AC1C		H2
AC1D	AC37	H3
AC38		H2
AC39	AC53	H3
AC54		H2
AC55	AC6F	H3
AC70		H2
AC71	AC8B	H3
AC8C		H2
AC8D	ACA7	H3
ACA8		H2
ACA9	ACC3	H3
ACC4		H2
ACC5	ACDF	H3
ACE0		H2
ACE1	ACFB	H3
ACFC		H2
ACFD	AD17	H3
AD18		H2
AD19	AD33	H3
AD34		H2
AD35	AD4F	H3
AD50		H2
AD51	AD6B	H3
AD6C		H2
AD6D	AD87	H3
AD88		H2
AD89	ADA3	H3
ADA4		H2
ADA5	ADBF	H3
ADC0		H2
ADC1	ADDB	H3
ADDC		H2
ADDD	ADF7	H3
ADF8		H2
ADF9	AE13	H3
AE14		H2
AE15	AE2F	H3
AE30		H2
AE31	AE4B	H3
AE4C		H2
AE4D	AE67	H3
AE68		H2
AE69	AE83	H3
AE84		H2
AE85	AE9F	H3
AEA0		H2
AEA1	AEBB	H3
AEBC		H2
AEBD	AED7	H3
AED8		H2
AED9	AEF3	H3
AEF4		H2
AEF5	AF0F	H3
AF10		H2
AF11	AF2B	H3
AF2C		H2
AF2D	AF47	H3
AF48		H2
AF49	AF63	H3
AF64		H2
AF65	AF7F	H3
AF80		H2
AF81	AF9B	H3
AF9C		H2
AF9D	AFB7	H3
AFB8		H2
AFB9	AFD3	H3
AFD4		H2
AFD5	AFEF	H3
AFF0		H2
AFF1	B00B	H3
B00C		H2
B00D	B027	H3
B028		H2
B029	B043	H3
B044		H2
B045	B05F	H3
B060		H2
B061	B07B	H3
B07C		H2
B07D	B097	H3
B098		H2
B099	B0B3	H3
B0B4		H2
B0B5	B0CF	H3
B0D0		H2
B0D1	B0EB	H3
B0EC		H2
B0ED	B107	H3
B108		H2
B109	B123	H3
B124		H2
B125	B13F	H3
B140		H2
B141	B15B	H3
B15C		H2
B15D	B177	H3
B178		H2
B179	B193	H3
B194		H2
B195	B1AF	H3
B1B0		H2
B1B1	B1CB	H3
B1CC		H2
B1CD	B1E7	H3
B1E8		H2
B1E9	B203	H3
B204		H2
B205	B21F	H3
B220		H2
B221	B23B	H3
B23C		H2
B23D	B257	H3
B258		H2
B259	B273	H3
B274		H2
B275	B28F	H3
B290		H2
B291	B2AB	H3
B2AC		H2
B2AD	B2C7	H3
B2C8		H2
B2C9	B2E3	H3
B2E4		H2
B2E5	B2FF	H3
B300		H2
B301	B31B	H3
B31C		H2
B31D	B337	H3
B338		H2
B339	B353	H3
B354		H2
B355	B36F	H3
B370		H2
B371	B38B	H3
B38C		H2
B38D	B3A7	H3
B3A8		H2
B3A9	B3C3	H3
B3C4		H2
B3C5	B3DF	H3
B3E0		H2
B3E1	B3FB	H3
B3FC		H2
B3FD	B417	H3
B418		H2
B419	B433	H3
B434		H2
B435	B44F	H3
B450		H2
B451	B46B	H3
B46C		H2
B46D	B487	H3
B488		H2
B489	B4A3	H3
B4A4		H2
B4A5	B4BF	H3
B4C0		H2
B4C1	B4DB	H3
B4DC		H2
B4DD	B4F7	H3
B4F8		H2
B4F9	B513	H3
B514		H2
B515	B52F	H3
B530		H2
B531	B54B	H3
B54C		H2
B54D	B567	H3
B568		H2
B569	B583	H3
B584		H2
B585	B59F	H3
B5A0		H2
B5A1	B5BB	H3
B5BC		H2
B5BD	B5D7	H3
B5D8		H2
B5D9	B5F3	H3
B5F4		H2
B5F5	B60F	H3
B610		H2
B611	B62B	H3
B62C		H2
B62D	B647	H3
B648		H2
B649	B663	H3
B664		H2
B665	B67F	H3
B680		H2
B681	B69B	H3
B69C		H2
B69D	B6B7	H3
B6B8		H2
B6B9	B6D3	H3
B6D4		H2
B6D5	B6EF	H3
B6F0		H2
B6F1	B70B	H3
B70C		H2
B70D	B727	H3
B728		H2
B729	B743	H3
B744		H2
B745	B75F	H3
B760		H2
B761	B77B	H3
B77C		H2
B77D	B797	H3
B798		H2
B799	B7B3	H3
B7B4		H2
B7B5	B7CF	H3
B7D0		H2
B7D1	B7EB	H3
B7EC		H2
B7ED	B807	H3
B808		H2
B809	B823	H3
B824		H2
B825	B83F	H3
B840		H2
B841	B85B	H3
B85C		H2
B85D	B877	H3
B878		H2
B879	B893	H3
B894		H2
B895	B8AF	H3
B8B0		H2
B8B1	B8CB	H3
B8CC		H2
B8CD	B8E7	H3
B8E8		H2
B8E9	B903	H3
B904		H2
B905	B91F	H3
B920		H2
B921	B93B	H3
B93C		H2
B93D	B957	H3
B958		H2
B959	B973	H3
B974		H2
B975	B98F	H3
B990		H2
B991	B9AB	H3
B9AC		H2
B9AD	B9C7	H3
B9C8		H2
B9C9	B9E3	H3
B9E4		H2
B9E5	B9FF	H3
BA00		H2
BA01	BA1B	H3
BA1C		H2
BA1D	BA37	H3
BA38		H2
BA39	BA53	H3
BA54		H2
BA55	BA6F	H3
BA70		H2
BA71	BA8B	H3
BA8C		H2
BA8D	BAA7	H3
BAA8		H2
BAA9	BAC3	H3
BAC4		H2
BAC5	BADF	H3
BAE0		H2
BAE1	BAFB	H3
BAFC		H2
BAFD	BB17	H3
BB18		H2
BB19	BB33	H3
BB34		H2
BB35	BB4F	H3
BB50		H2
BB51	BB6B	H3
BB6C		H2
BB6D	BB87	H3
BB88		H2
BB89	BBA3	H3
BBA4		H2
BBA5	BBBF	H3
BBC0		H2
BBC1	BBDB	H3
BBDC		H2
BBDD	BBF7	H3
BBF8		H2
BBF9	BC13	H3
BC14		H2
BC15	BC2F	H3
BC30		H2
BC31	BC4B	H3
BC4C		H2
BC4D	BC67	H3
BC68		H2
BC69	BC83	H3
BC84		H2
BC85	BC9F	H3
BCA0		H2
BCA1	BCBB	H3
BCBC		H2
BCBD	BCD7	H3
BCD8		H2
BCD9	BCF3	H3
BCF4		H2
BCF5	BD0F	H3
BD10		H2
BD11	BD2B	H3
BD2C		H2
BD2D	BD47	H3
BD48		H2
BD49	BD63	H3
BD64		H2
BD65	BD7F	H3
BD80		H2
BD81	BD9B	H3
BD9C		H2
BD9D	BDB7	H3
BDB8		H2
BDB9	BDD3	H3
BDD4		H2
BDD5	BDEF	H3
BDF0		H2
BDF1	BE0B	H3
BE0C		H2
BE0D	BE27	H3
BE28		H2
BE29	BE43	H3
BE44		H2
BE45	BE5F	H3
BE60		H2
BE61	BE7B	H3
BE7C		H2
BE7D	BE97	H3
BE98		H2
BE99	BEB3	H3
BEB4		H2
BEB5	BECF	H3
BED0		H2
BED1	BEEB	H3
BEEC		H2
BEED	BF07	H3
BF08		H2
BF09	BF23	H3
BF24		H2
BF25	BF3F	H3
BF40		H2
BF41	BF5B	H3
BF5C		H2
BF5D	BF77	H3
BF78		H2
BF79	BF93	H3
BF94		H2
BF95	BFAF	H3
BFB0		H2
BFB1	BFCB	H3
BFCC		H2
BFCD	BFE7	H3
BFE8		H2
BFE9	C003	H3
C004		H2
C005	C01F	H3
C020		H2
C021	C03B	H3
C03C		H2
C03D	C057	H3
C058		H2
C059	C073	H3
C074		H2
C075	C08F	H3
C090		H2
C091	C0AB	H3
C0AC		H2
C0AD	C0C7	H3
C0C8		H2
C0C9	C0E3	H3
C0E4		H2
C0E5	C0FF	H3
C100		H2
C101	C11B	H3
C11C		H2
C11D	C137	H3
C138		H2
C139	C153	H3
C154		H2
C155	C16F	H3
C170		H2
C171	C18B	H3
C18C		H2
C18D	C1A7	H3
C1A8		H2
C1A9	C1C3	H3
C1C4		H2
C1C5	C1DF	H3
C1E0		H2
C1E1	C1FB	H3
C1FC		H2
C1FD	C217	H3
C218		H2
C219	C233	H3
C234		H2
C235	C24F	H3
C250		H2
C251	C26B	H3
C26C		H2
C26D	C287	H3
C288		H2
C289	C2A3	H3
C2A4		H2
C2A5	C2BF	H3
C2C0		H2
C2C1	C2DB	H3
C2DC		H2
C2DD	C2F7	H3
C2F8		H2
C2F9	C313	H3
C314		H2
C315	C32F	H3
C330		H2
C331	C34B	H3
C34C		H2
C34D	C367	H3
C368		H2
C369	C383	H3
C384		H2
C385	C39F	H3
C3A0		H2
C3A1	C3BB	H3
C3BC		H2
C3BD	C3D7	H3
C3D8		H2
C3D9	C3F3	H3
C3F4		H2
C3F5	C40F	H3
C410		H2
C411	C42B	H3
C42C		H2
C42D	C447	H3
C448		H2
C449	C463	H3
C464		H2
C465	C47F	H3
C480		H2
C481	C49B	H3
C49C		H2
C49D	C4B7	H3
C4B8		H2
C4B9	C4D3	H3
C4D4		H2
C4D5	C4EF	H3
C4F0		H2
C4F1	C50B	H3
C50C		H2
C50D	C527	H3
C528		H2
C529	C543	H3
C544		H2
C545	C55F	H3
C560		H2
C561	C57B	H3
C57C		H2
C57D	C597	H3
C598		H2
C599	C5B3	H3
C5B4		H2
C5B5	C5CF	H3
C5D0		H2
C5D1	C5EB	H3
C5EC		H2
C5ED	C607	H3
C608		H2
C609	C623	H3
C624		H2
C625	C63F	H3
C640		H2
C641	C65B	H3
C65C		H2
C65D	C677	H3
C678		H2
C679	C693	H3
C694		H2
C695	C6AF	H3
C6B0		H2
C6B1	C6CB	H3
C6CC		H2
C6CD	C6E7	H3
C6E8		H2
C6E9	C703	H3
C704		H2
C705	C71F	H3
C720		H2
C721	C73B	H3
C73C		H2
C73D	C757	H3
C758		H2
C759	C773	H3
C774		H2
C775	C78F	H3
C790		H2
C791	C7AB	H3
C7AC		H2
C7AD	C7C7	H3
C7C8		H2
C7C9	C7E3	H3
C7E4		H2
C7E5	C7FF	H3
C800		H2
C801	C81B	H3
C81C		H2
C81D	C837	H3
C838		H2
C839	C853	H3
C854		H2
C855	C86F	H3
C870		H2
C871	C88B	H3
C88C		H2
C88D	C8A7	H3
C8A8		H2
C8A9	C8C3	H3
C8C4		H2
C8C5	C8DF	H3
C8E0		H2
C8E1	C8FB	H3
C8FC		H2
C8FD	C917	H3
C918		H2
C919	C933	H3
C934		H2
C935	C94F	H3
C950		H2
C951	C96B	H3
C96C		H2
C96D	C987	H3
C988		H2
C989	C9A3	H3
C9A4		H2
C9A5	C9BF	H3
C9C0		H2
C9C1	C9DB	H3
C9DC		H2
C9DD	C9F7	H3
C9F8		H2
C9F9	CA13	H3
CA14		H2
CA15	CA2F	H3
CA30		H2
CA31	CA4B	H3
CA4C		H2
CA4D	CA67	H3
CA68		H2
CA69	CA83	H3
CA84		H2
CA85	CA9F	H3
CAA0		H2
CAA1	CABB	H3
CABC		H2
CABD	CAD7	H3
CAD8		H2
CAD9	CAF3	H3
CAF4		H2
CAF5	CB0F	H3
CB10		H2
CB11	CB2B	H3
CB2C		H2
CB2D	CB47	H3
CB48		H2
CB49	CB63	H3
CB64		H2
CB65	CB7F	H3
CB80		H2
CB81	CB9B	H3
CB9C		H2
CB9D	CBB7	H3
CBB8		H2
CBB9	CBD3	H3
CBD4		H2
CBD5	CBEF	H3
CBF0		H2
CBF1	CC0B	H3
CC0C		H2
CC0D	CC27	H3
CC28		H2
CC29	CC43	H3
CC44		H2
CC45	CC5F	H3
CC60		H2
CC61	CC7B	H3
CC7C		H2
CC7D	CC97	H3
CC98		H2
CC99	CCB3	H3
CCB4		H2
CCB5	CCCF	H3
CCD0		H2
CCD1	CCEB	H3
CCEC		H2
CCED	CD07	H3
CD08		H2
CD09	CD23	H3
CD24		H2
CD25	CD3F	H3
CD40		H2
CD41	CD5B	H3
CD5C		H2
CD5D	CD77	H3
CD78		H2
CD79	CD93	H3
CD94		H2
CD95	CDAF	H3
CDB0		H2
CDB1	CDCB	H3
CDCC		H2
CDCD	CDE7	H3
CDE8		H2
CDE9	CE03	H3
CE04		H2
CE05	CE1F	H3
CE20		H2
CE21	CE3B	H3
CE3C		H2
CE3D	CE57	H3
CE58		H2
CE59	CE73	H3
CE74		H2
CE75	CE8F	H3
CE90		H2
CE91	CEAB	H3
CEAC		H2
CEAD	CEC7	H3
CEC8		H2
CEC9	CEE3	H3
CEE4		H2
CEE5	CEFF	H3
CF00		H2
CF01	CF1B	H3
CF1C		H2
CF1D	CF37	H3
CF38		H2
CF39	CF53	H3
CF54		H2
CF55	CF6F	H3
CF70		H2
CF71	CF8B	H3
CF8C		H2
CF8D	CFA7	H3
CFA8		H2
CFA9	CFC3	H3
CFC4		H2
CFC5	CFDF	H3
CFE0		H2
CFE1	CFFB	H3
CFFC		H2
CFFD	D017	H3
D018		H2
D019	D033	H3
D034		H2
D035	D04F	H3
D050		H2
D051	D06B	H3
D06C		H2
D06D	D087	H3
D088		H2
D089	D0A3	H3
D0A4		H2
D0A5	D0BF	H3
D0C0		H2
D0C1	D0DB	H3
D0DC		H2
D0DD	D0F7	H3
D0F8		H2
D0F9	D113	H3
D114		H2
D115	D12F	H3
D130		H2
D131	D14B	H3
D14C		H2
D14D	D167	H3
D168		H2
D169	D183	H3
D184		H2
D185	D19F	H3
D1A0		H2
D1A1	D1BB	H3
D1BC		H2
D1BD	D1D7	H3
D1D8		H2
D1D9	D1F3	H3
D1F4		H2
D1F5	D20F	H3
D210		H2
D211	D22B	H3
D22C		H2
D22D	D247	H3
D248		H2
D249	D263	H3
D264		H2
D265	D27F	H3
D280		H2
D281	D29B	H3
D29C		H2
D29D	D2B7	H3
D2B8		H2
D2B9	D2D3	H3
D2D4		H2
D2D5	D2EF	H3
D2F0		H2
D2F1	D30B	H3
D30C		H2
D30D	D327	H3
D328		H2
D329	D343	H3
D344		H2
D345	D35F	H3
D360		H2
D361	D37B	H3
D37C		H2
D37D	D397	H3
D398		H2
D399	D3B3	H3
D3B4		H2
D3B5	D3CF	H3
D3D0		H2
D3D1	D3EB	H3
D3EC		H2
D3ED	D407	H3
D408		H2
D409	D423	H3
D424		H2
D425	D43F	H3
D440		H2
D441	D45B	H3
D45C		H2
D45D	D477	H3
D478		H2
D479	D493	H3
D494		H2
D495	D4AF	H3
D4B0		H2
D4B1	D4CB	H3
D4CC		H2
D4CD	D4E7	H3
D4E8		H2
D4E9	D503	H3
D504		H2
D505	D51F	H3
D520		H2
D521	D53B	H3
D53C		H2
D53D	D557	H3
D558		H2
D559	D573	H3
D574		H2
D575	D58F	H3
D590		H2
D591	D5AB	H3
D5AC		H2
D5AD	D5C7	H3
D5C8		H2
D5C9	D5E3	H3
D5E4		H2
D5E5	D5FF	H3
D600		H2
D601	D61B	H3
D61C		H2
D61D	D637	H3
D638		H2
D639	D653	H3
D654		H2
D655	D66F	H3
D670		H2
D671	D68B	H3
D68C		H2
D68D	D6A7	H3
D6A8		H2
D6A9	D6C3	H3
D6C4		H2
D6C5	D6DF	H3
D6E0		H2
D6E1	D6FB	H3
D6FC		H2
D6FD	D717	H3
D718		H2
D719	D733	H3
D734		H2
D735	D74F	H3
D750		H2
D751	D76B	H3
D76C		H2
D76D	D787	H3
D788		H2
D789	D7A3	H3
D7B0	D7C6	JV
D7CB	D7FB	JT
F900	FAFF	Ideographic
FB1D		Hebrew_Letter
FB1E		Combining_Mark
FB1F	FB28	Hebrew_Letter
FB2A	FB36	Hebrew_Letter
FB38	FB3C	Hebrew_Letter
FB3E		Hebrew_Letter
FB40	FB41	Hebrew_Letter
FB43	FB44	Hebrew_Letter
FB46	FB4F	Hebrew_Letter
FD3E		Close_Punctuation
FD3F		Open_Punctuation
FDFC		Postfix_Numeric
FE00	FE0F	Combining_Mark
FE10		Infix_Numeric
FE11	FE12	Close_Punctuation
FE13	FE14	Infix_Numeric
FE15	FE16	Exclamation
FE17		East_Asian_OP
FE18		Close_Punctuation
FE19		Inseparable
FE20	FE2F	Combining_Mark
FE30	FE34	Ideographic
FE35		East_Asian_OP
FE36		Close_Punctuation
FE37		East_Asian_OP
FE38		Close_Punctuation
FE39		East_Asian_OP
FE3A		Close_Punctuation
FE3B		East_Asian_OP
FE3C		Close_Punctuation
FE3D		East_Asian_OP
FE3E		Close_Punctuation
FE3F		East_Asian_OP
FE40		Close_Punctuation
FE41		East_Asian_OP
FE42		Close_Punctuation
FE43		East_Asian_OP
FE44		Close_Punctuation
FE45	FE46	Ideographic
FE47		East_Asian_OP
FE48		Close_Punctuation
FE49	FE4F	Ideographic
FE50		Close_Punctuation
FE51		Ideographic
FE52		Close_Punctuation
FE54	FE55	Nonstarter
FE56	FE57	Exclamation
FE58		Ideographic
FE59		East_Asian_OP
FE5A		Close_Punctuation
FE5B		East_Asian_OP
FE5C		Close_Punctuation
FE5D		East_Asian_OP
FE5E		Close_Punctuation
FE5F	FE66	Ideographic
FE68		Ideographic
FE69		Prefix_Numeric
FE6A		Postfix_Numeric
FE6B		Ideographic
FEFF		Word_Joiner
FF01		Exclamation
FF02	FF03	Ideographic
FF04		Prefix_Numeric
FF05		Postfix_Numeric
FF06	FF07	Ideographic
FF08		East_Asian_OP
FF09		Close_Punctuation
FF0A	FF0B	Ideographic
FF0C		Close_Punctuation
FF0D		Ideographic
FF0E		Close_Punctuation
FF0F	FF19	Ideographic
FF1A	FF1B	Nonstarter
FF1C	FF1E	Ideographic
FF1F		Exclamation
FF20	FF3A	Ideographic
FF3B		East_Asian_OP
FF3C		Ideographic
FF3D		Close_Punctuation
FF3E	FF5A	Ideographic
FF5B		East_Asian_OP
FF5C		Ideographic
FF5D		Close_Punctuation
FF5E		Ideographic
FF5F		East_Asian_OP
FF60	FF61	Close_Punctuation
FF62		East_Asian_OP
FF63	FF64	Close_Punctuation
FF65		Nonstarter
FF66		Ideographic
FF67	FF70	Nonstarter
FF71	FF9D	Ideographic
FF9E	FF9F	Nonstarter
FFA0	FFBE	Ideographic
FFC2	FFC7	Ideographic
FFCA	FFCF	Ideographic
FFD2	FFD7	Ideographic
FFDA	FFDC	Ideographic
FFE0		Postfix_Numeric
FFE1		Prefix_Numeric
FFE2	FFE4	Ideographic
FFE5	FFE6	Prefix_Numeric
FFF9	FFFB	Combining_Mark
FFFC		Contingent_Break
10100	10102	Break_After
101FD		Combining_Mark
102E0		Combining_Mark
10376	1037A	Combining_Mark
1039F		Break_After
103D0		Break_After
104A0	104A9	Numeric
10857		Break_After
1091F		Break_After
10A01	10A03	Combining_Mark
10A05	10A06	Combining_Mark
10A0C	10A0F	Combining_Mark
10A38	10A3A	Combining_Mark
10A3F		Combining_Mark
10A50	10A57	Break_After
10AE5	10AE6	Combining_Mark
10AF0	10AF5	Break_After
10AF6		Inseparable
10B39	10B3F	Break_After
10D24	10D27	Combining_Mark
10D30	10D39	Numeric
10EAB	10EAC	Combining_Mark
10EAD		Break_After
10F46	10F50	Combining_Mark
10F82	10F85	Combining_Mark
11000	11002	Combining_Mark
11038	11046	Combining_Mark
11047	11048	Break_After
11066	1106F	Numeric
11070		Combining_Mark
11073	11074	Combining_Mark
1107F	11082	Combining_Mark
110B0	110BA	Combining_Mark
110BE	110C1	Break_After
110C2		Combining_Mark
110F0	110F9	Numeric
11100	11102	Combining_Mark
11127	11134	Combining_Mark
11136	1113F	Numeric
11140	11143	Break_After
11145	11146	Combining_Mark
11173		Combining_Mark
11175		Break_Before
11180	11182	Combining_Mark
111B3	111C0	Combining_Mark
111C5	111C6	Break_After
111C8		Break_After
111C9	111CC	Combining_Mark
111CE	111CF	Combining_Mark
111D0	111D9	Numeric
111DB		Break_Before
111DD	111DF	Break_After
1122C	11237	Combining_Mark
11238	11239	Break_After
1123B	1123C	Break_After
1123E		Combining_Mark
112A9		Break_After
112DF	112EA	Combining_Mark
112F0	112F9	Numeric
11300	11303	Combining_Mark
1133B	1133C	Combining_Mark
1133E	11344	Combining_Mark
11347	11348	Combining_Mark
1134B	1134D	Combining_Mark
11357		Combining_Mark
11362	11363	Combining_Mark
11366	1136C	Combining_Mark
11370	11374	Combining_Mark
11435	11446	Combining_Mark
1144B	1144E	Break_After
11450	11459	Numeric
1145A	1145B	Break_After
1145E		Combining_Mark
114B0	114C3	Combining_Mark
114D0	114D9	Numeric
115AF	115B5	Combining_Mark
115B8	115C0	Combining_Mark
115C1		Break_Before
115C2	115C3	Break_After
115C4	115C5	Exclamation
115C9	115D7	Break_After
115DC	115DD	Combining_Mark
11630	11640	Combining_Mark
11641	11642	Break_After
11650	11659	Numeric
11660	1166C	Break_Before
116AB	116B7	Combining_Mark
116C0	116C9	Numeric
1171D	1172B	Combining_Mark
11730	11739	Numeric
1173C	1173E	Break_After
1182C	1183A	Combining_Mark
118E0	118E9	Numeric
11930	11935	Combining_Mark
11937	11938	Combining_Mark
1193B	1193E	Combining_Mark
11940		Combining_Mark
11942	11943	Combining_Mark
11944	11946	Break_After
11950	11959	Numeric
119D1	119D7	Combining_Mark
119DA	119E0	Combining_Mark
119E2		Break_Before
119E4		Combining_Mark
11A01	11A0A	Combining_Mark
11A33	11A39	Combining_Mark
11A3B	11A3E	Combining_Mark
11A3F		Break_Before
11A41	11A44	Break_After
11A45		Break_Before
11A47		Combining_Mark
11A51	11A5B	Combining_Mark
11A8A	11A99	Combining_Mark
11A9A	11A9C	Break_After
11A9E	11AA0	Break_Before
11AA1	11AA2	Break_After
11C2F	11C36	Combining_Mark
11C38	11C3F	Combining_Mark
11C41	11C45	Break_After
11C50	11C59	Numeric
11C70		Break_Before
11C71		Exclamation
11C92	11CA7	Combining_Mark
11CA9	11CB6	Combining_Mark
11D31	11D36	Combining_Mark
11D3A		Combining_Mark
11D3C	11D3D	Combining_Mark
11D3F	11D45	Combining_Mark
11D47		Combining_Mark
11D50	11D59	Numeric
11D8A	11D8E	Combining_Mark
11D90	11D91	Combining_Mark
11D93	11D97	Combining_Mark
11DA0	11DA9	Numeric
11EF3	11EF6	Combining_Mark
11FDD	11FE0	Postfix_Numeric
11FFF		Break_After
12470	12474	Break_After
13258	1325A	Open_Punctuation
1325B	1325D	Close_Punctuation
13282		Close_Punctuation
13286		Open_Punctuation
13287		Close_Punctuation
13288		Open_Punctuation
13289		Close_Punctuation
13379		Open_Punctuation
1337A	1337B	Close_Punctuation
13430	13436	Glue
13437		Open_Punctuation
13438		Close_Punctuation
145CE		Open_Punctuation
145CF		Close_Punctuation
16A60	16A69	Numeric
16A6E	16A6F	Break_After
16AC0	16AC9	Numeric
16AF0	16AF4	Combining_Mark
16AF5		Break_After
16B30	16B36	Combining_Mark
16B37	16B39	Break_After
16B44		Break_After
16B50	16B59	Numeric
16E97	16E98	Break_After
16F4F		Combining_Mark
16F51	16F87	Combining_Mark
16F8F	16F92	Combining_Mark
16FE0	16FE3	Nonstarter
16FE4		Glue
16FF0	16FF1	Combining_Mark
17000	187F7	Ideographic
18800	18AFF	Ideographic
18D00	18D08	Ideographic
1B000	1B122	Ideographic
1B150	1B152	Nonstarter
1B164	1B167	Nonstarter
1B170	1B2FB	Ideographic
1BC9D	1BC9E	Combining_Mark
1BC9F		Break_After
1BCA0	1BCA3	Combining_Mark
1CF00	1CF2D	Combining_Mark
1CF30	1CF46	Combining_Mark
1D165	1D169	Combining_Mark
1D16D	1D182	Combining_Mark
1D185	1D18B	Combining_Mark
1D1AA	1D1AD	Combining_Mark
1D242	1D244	Combining_Mark
1D7CE	1D7FF	Numeric
1DA00	1DA36	Combining_Mark
1DA3B	1DA6C	Combining_Mark
1DA75		Combining_Mark
1DA84		Combining_Mark
1DA87	1DA8A	Break_After
1DA9B	1DA9F	Combining_Mark
1DAA1	1DAAF	Combining_Mark
1E000	1E006	Combining_Mark
1E008	1E018	Combining_Mark
1E01B	1E021	Combining_Mark
1E023	1E024	Combining_Mark
1E026	1E02A	Combining_Mark
1E130	1E136	Combining_Mark
1E140	1E149	Numeric
1E2AE		Combining_Mark
1E2EC	1E2EF	Combining_Mark
1E2F0	1E2F9	Numeric
1E2FF		Prefix_Numeric
1E8D0	1E8D6	Combining_Mark
1E944	1E94A	Combining_Mark
1E950	1E959	Numeric
1E95E	1E95F	Open_Punctuation
1ECAC		Postfix_Numeric
1ECB0		Postfix_Numeric
1F000	1F02B	Ideographic
1F02C	1F02F	Unassigned_Extended_Pictographic_Ideographic
1F030	1F093	Ideographic
1F094	1F09F	Unassigned_Extended_Pictographic_Ideographic
1F0A0	1F0AE	Ideographic
1F0AF	1F0B0	Unassigned_Extended_Pictographic_Ideographic
1F0B1	1F0BF	Ideographic
1F0C0		Unassigned_Extended_Pictographic_Ideographic
1F0C1	1F0CF	Ideographic
1F0D0		Unassigned_Extended_Pictographic_Ideographic
1F0D1	1F0F5	Ideographic
1F0F6	1F0FF	Unassigned_Extended_Pictographic_Ideographic
1F10D	1F10F	Ideographic
1F16D	1F16F	Ideographic
1F1AD		Ideographic
1F1AE	1F1E5	Unassigned_Extended_Pictographic_Ideographic
1F1E6	1F1FF	Regional_Indicator
1F200	1F202	Ideographic
1F203	1F20F	Unassigned_Extended_Pictographic_Ideographic
1F210	1F23B	Ideographic
1F23C	1F23F	Unassigned_Extended_Pictographic_Ideographic
1F240	1F248	Ideographic
1F249	1F24F	Unassigned_Extended_Pictographic_Ideographic
1F250	1F251	Ideographic
1F252	1F25F	Unassigned_Extended_Pictographic_Ideographic
1F260	1F265	Ideographic
1F266	1F2FF	Unassigned_Extended_Pictographic_Ideographic
1F300	1F384	Ideographic
1F385		E_Base
1F386	1F39B	Ideographic
1F39E	1F3B4	Ideographic
1F3B7	1F3BB	Ideographic
1F3BD	1F3C1	Ideographic
1F3C2	1F3C4	E_Base
1F3C5	1F3C6	Ideographic
1F3C7		E_Base
1F3C8	1F3C9	Ideographic
1F3CA	1F3CC	E_Base
1F3CD	1F3FA	Ideographic
1F3FB	1F3FF	E_Modifier
1F400	1F441	Ideographic
1F442	1F443	E_Base
1F444	1F445	Ideographic
1F446	1F450	E_Base
1F451	1F465	Ideographic
1F466	1F478	E_Base
1F479	1F47B	Ideographic
1F47C		E_Base
1F47D	1F480	Ideographic
1F481	1F483	E_Base
1F484		Ideographic
1F485	1F487	E_Base
1F488	1F48E	Ideographic
1F48F		E_Base
1F490		Ideographic
1F491		E_Base
1F492	1F49F	Ideographic
1F4A1		Ideographic
1F4A3		Ideographic
1F4A5	1F4A9	Ideographic
1F4AA		E_Base
1F4AB	1F4AE	Ideographic
1F4B0		Ideographic
1F4B3	1F4FF	Ideographic
1F507	1F516	Ideographic
1F525	1F531	Ideographic
1F54A	1F573	Ideographic
1F574	1F575	E_Base
1F576	1F579	Ideographic
1F57A		E_Base
1F57B	1F58F	Ideographic
1F590		E_Base
1F591	1F594	Ideographic
1F595	1F596	E_Base
1F597	1F5D3	Ideographic
1F5DC	1F5F3	Ideographic
1F5FA	1F644	Ideographic
1F645	1F647	E_Base
1F648	1F64A	Ideographic
1F64B	1F64F	E_Base
1F676	1F678	Quotation
1F679	1F67B	Nonstarter
1F680	1F6A2	Ideographic
1F6A3		E_Base
1F6A4	1F6B3	Ideographic
1F6B4	1F6B6	E_Base
1F6B7	1F6BF	Ideographic
1F6C0		E_Base
1F6C1	1F6CB	Ideographic
1F6CC		E_Base
1F6CD	1F6D7	Ideographic
1F6D8	1F6DC	Unassigned_Extended_Pictographic_Ideographic
1F6DD	1F6EC	Ideographic
1F6ED	1F6EF	Unassigned_Extended_Pictographic_Ideographic
1F6F0	1F6FC	Ideographic
1F6FD	1F6FF	Unassigned_Extended_Pictographic_Ideographic
1F774	1F77F	Unassigned_Extended_Pictographic_Ideographic
1F7D5	1F7D8	Ideographic
1F7D9	1F7DF	Unassigned_Extended_Pictographic_Ideographic
1F7E0	1F7EB	Ideographic
1F7EC	1F7EF	Unassigned_Extended_Pictographic_Ideographic
1F7F0		Ideographic
1F7F1	1F7FF	Unassigned_Extended_Pictographic_Ideographic
1F80C	1F80F	Unassigned_Extended_Pictographic_Ideographic
1F848	1F84F	Unassigned_Extended_Pictographic_Ideographic
1F85A	1F85F	Unassigned_Extended_Pictographic_Ideographic
1F888	1F88F	Unassigned_Extended_Pictographic_Ideographic
1F8AE	1F8AF	Unassigned_Extended_Pictographic_Ideographic
1F8B0	1F8B1	Ideographic
1F8B2	1F8FF	Unassigned_Extended_Pictographic_Ideographic
1F90C		E_Base
1F90D	1F90E	Ideographic
1F90F		E_Base
1F910	1F917	Ideographic
1F918	1F91F	E_Base
1F920	1F925	Ideographic
1F926		E_Base
1F927	1F92F	Ideographic
1F930	1F939	E_Base
1F93A	1F93B	Ideographic
1F93C	1F93E	E_Base
1F93F	1F976	Ideographic
1F977		E_Base
1F978	1F9B4	Ideographic
1F9B5	1F9B6	E_Base
1F9B7		Ideographic
1F9B8	1F9B9	E_Base
1F9BA		Ideographic
1F9BB		E_Base
1F9BC	1F9CC	Ideographic
1F9CD	1F9CF	E_Base
1F9D0		Ideographic
1F9D1	1F9DD	E_Base
1F9DE	1F9FF	Ideographic
1FA54	1FA5F	Unassigned_Extended_Pictographic_Ideographic
1FA60	1FA6D	Ideographic
1FA6E	1FA6F	Unassigned_Extended_Pictographic_Ideographic
1FA70	1FA74	Ideographic
1FA75	1FA77	Unassigned_Extended_Pictographic_Ideographic
1FA78	1FA7C	Ideographic
1FA7D	1FA7F	Unassigned_Extended_Pictographic_Ideographic
1FA80	1FA86	Ideographic
1FA87	1FA8F	Unassigned_Extended_Pictographic_Ideographic
1FA90	1FAAC	Ideographic
1FAAD	1FAAF	Unassigned_Extended_Pictographic_Ideographic
1FAB0	1FABA	Ideographic
1FABB	1FABF	Unassigned_Extended_Pictographic_Ideographic
1FAC0	1FAC2	Ideographic
1FAC3	1FAC5	E_Base
1FAC6	1FACF	Unassigned_Extended_Pictographic_Ideographic
1FAD0	1FAD9	Ideographic
1FADA	1FADF	Unassigned_Extended_Pictographic_Ideographic
1FAE0	1FAE7	Ideographic
1FAE8	1FAEF	Unassigned_Extended_Pictographic_Ideographic
1FAF0	1FAF6	E_Base
1FAF7	1FAFF	Unassigned_Extended_Pictographic_Ideographic
1FBF0	1FBF9	Numeric
1FC00	1FFFD	Unassigned_Extended_Pictographic_Ideographic
20000	2FFFD	Ideographic
30000	3FFFD	Ideographic
E0001		Combining_Mark
E0020	E007F	Combining_Mark
E0100	E01EF	Combining_Mark
END
