# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 14.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToIdentifierStatus'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToIdentifierStatus'}{'missing'} = 'Restricted';

return <<'END';
27		Allowed
2D	2E	Allowed
30	3A	Allowed
41	5A	Allowed
5F		Allowed
61	7A	Allowed
B7		Allowed
C0	D6	Allowed
D8	F6	Allowed
F8	131	Allowed
134	13E	Allowed
141	148	Allowed
14A	17E	Allowed
18F		Allowed
1A0	1A1	Allowed
1AF	1B0	Allowed
1CD	1DC	Allowed
1DE	1E3	Allowed
1E6	1F0	Allowed
1F4	1F5	Allowed
1F8	21B	Allowed
21E	21F	Allowed
226	233	Allowed
259		Allowed
2BB	2BC	Allowed
2EC		Allowed
300	304	Allowed
306	30C	Allowed
30F	311	Allowed
313	314	Allowed
31B		Allowed
323	328	Allowed
32D	32E	Allowed
330	331	Allowed
335		Allowed
338	339	Allowed
342		Allowed
345		Allowed
375		Allowed
37B	37D	Allowed
386		Allowed
388	38A	Allowed
38C		Allowed
38E	3A1	Allowed
3A3	3CE	Allowed
3FC	45F	Allowed
48A	4FF	Allowed
510	529	Allowed
52E	52F	Allowed
531	556	Allowed
559		Allowed
561	586	Allowed
58A		Allowed
5B4		Allowed
5D0	5EA	Allowed
5EF	5F4	Allowed
620	63F	Allowed
641	655	Allowed
660	669	Allowed
670	672	Allowed
674		Allowed
679	68D	Allowed
68F	6A0	Allowed
6A2	6D3	Allowed
6D5		Allowed
6E5	6E6	Allowed
6EE	6FF	Allowed
750	7B1	Allowed
870	887	Allowed
889	88E	Allowed
8A0	8AC	Allowed
8B2		Allowed
8B5	8C9	Allowed
901	94D	Allowed
94F	950	Allowed
956	957	Allowed
960	963	Allowed
966	96F	Allowed
971	977	Allowed
979	97F	Allowed
981	983	Allowed
985	98C	Allowed
98F	990	Allowed
993	9A8	Allowed
9AA	9B0	Allowed
9B2		Allowed
9B6	9B9	Allowed
9BC	9C4	Allowed
9C7	9C8	Allowed
9CB	9CE	Allowed
9D7		Allowed
9E0	9E3	Allowed
9E6	9F1	Allowed
9FE		Allowed
A01	A03	Allowed
A05	A0A	Allowed
A0F	A10	Allowed
A13	A28	Allowed
A2A	A30	Allowed
A32		Allowed
A35		Allowed
A38	A39	Allowed
A3C		Allowed
A3E	A42	Allowed
A47	A48	Allowed
A4B	A4D	Allowed
A5C		Allowed
A66	A74	Allowed
A81	A83	Allowed
A85	A8D	Allowed
A8F	A91	Allowed
A93	AA8	Allowed
AAA	AB0	Allowed
AB2	AB3	Allowed
AB5	AB9	Allowed
ABC	AC5	Allowed
AC7	AC9	Allowed
ACB	ACD	Allowed
AD0		Allowed
AE0	AE3	Allowed
AE6	AEF	Allowed
AFA	AFF	Allowed
B01	B03	Allowed
B05	B0C	Allowed
B0F	B10	Allowed
B13	B28	Allowed
B2A	B30	Allowed
B32	B33	Allowed
B35	B39	Allowed
B3C	B43	Allowed
B47	B48	Allowed
B4B	B4D	Allowed
B55	B57	Allowed
B5F	B61	Allowed
B66	B6F	Allowed
B71		Allowed
B82	B83	Allowed
B85	B8A	Allowed
B8E	B90	Allowed
B92	B95	Allowed
B99	B9A	Allowed
B9C		Allowed
B9E	B9F	Allowed
BA3	BA4	Allowed
BA8	BAA	Allowed
BAE	BB9	Allowed
BBE	BC2	Allowed
BC6	BC8	Allowed
BCA	BCD	Allowed
BD0		Allowed
BD7		Allowed
BE6	BEF	Allowed
C01	C0C	Allowed
C0E	C10	Allowed
C12	C28	Allowed
C2A	C33	Allowed
C35	C39	Allowed
C3C	C44	Allowed
C46	C48	Allowed
C4A	C4D	Allowed
C55	C56	Allowed
C5D		Allowed
C60	C61	Allowed
C66	C6F	Allowed
C80		Allowed
C82	C83	Allowed
C85	C8C	Allowed
C8E	C90	Allowed
C92	CA8	Allowed
CAA	CB3	Allowed
CB5	CB9	Allowed
CBC	CC4	Allowed
CC6	CC8	Allowed
CCA	CCD	Allowed
CD5	CD6	Allowed
CDD		Allowed
CE0	CE3	Allowed
CE6	CEF	Allowed
CF1	CF2	Allowed
D00		Allowed
D02	D03	Allowed
D05	D0C	Allowed
D0E	D10	Allowed
D12	D3A	Allowed
D3D	D43	Allowed
D46	D48	Allowed
D4A	D4E	Allowed
D54	D57	Allowed
D60	D61	Allowed
D66	D6F	Allowed
D7A	D7F	Allowed
D82	D83	Allowed
D85	D8E	Allowed
D91	D96	Allowed
D9A	DA5	Allowed
DA7	DB1	Allowed
DB3	DBB	Allowed
DBD		Allowed
DC0	DC6	Allowed
DCA		Allowed
DCF	DD4	Allowed
DD6		Allowed
DD8	DDE	Allowed
DF2		Allowed
E01	E32	Allowed
E34	E3A	Allowed
E40	E4E	Allowed
E50	E59	Allowed
E81	E82	Allowed
E84		Allowed
E86	E8A	Allowed
E8C	EA3	Allowed
EA5		Allowed
EA7	EB2	Allowed
EB4	EBD	Allowed
EC0	EC4	Allowed
EC6		Allowed
EC8	ECD	Allowed
ED0	ED9	Allowed
EDE	EDF	Allowed
F00		Allowed
F0B		Allowed
F20	F29	Allowed
F35		Allowed
F37		Allowed
F3E	F42	Allowed
F44	F47	Allowed
F49	F4C	Allowed
F4E	F51	Allowed
F53	F56	Allowed
F58	F5B	Allowed
F5D	F68	Allowed
F6A	F6C	Allowed
F71	F72	Allowed
F74		Allowed
F7A	F80	Allowed
F82	F84	Allowed
F86	F92	Allowed
F94	F97	Allowed
F99	F9C	Allowed
F9E	FA1	Allowed
FA3	FA6	Allowed
FA8	FAB	Allowed
FAD	FB8	Allowed
FBA	FBC	Allowed
FC6		Allowed
1000	1049	Allowed
1050	109D	Allowed
10C7		Allowed
10CD		Allowed
10D0	10F0	Allowed
10F7	10FA	Allowed
10FD	10FF	Allowed
1200	1248	Allowed
124A	124D	Allowed
1250	1256	Allowed
1258		Allowed
125A	125D	Allowed
1260	1288	Allowed
128A	128D	Allowed
1290	12B0	Allowed
12B2	12B5	Allowed
12B8	12BE	Allowed
12C0		Allowed
12C2	12C5	Allowed
12C8	12D6	Allowed
12D8	1310	Allowed
1312	1315	Allowed
1318	135A	Allowed
135D	135F	Allowed
1380	138F	Allowed
1780	17A2	Allowed
17A5	17A7	Allowed
17A9	17B3	Allowed
17B6	17CD	Allowed
17D0		Allowed
17D2		Allowed
17D7		Allowed
17DC		Allowed
17E0	17E9	Allowed
1C90	1CBA	Allowed
1CBD	1CBF	Allowed
1E00	1E99	Allowed
1E9E		Allowed
1EA0	1EF9	Allowed
1F00	1F15	Allowed
1F18	1F1D	Allowed
1F20	1F45	Allowed
1F48	1F4D	Allowed
1F50	1F57	Allowed
1F59		Allowed
1F5B		Allowed
1F5D		Allowed
1F5F	1F70	Allowed
1F72		Allowed
1F74		Allowed
1F76		Allowed
1F78		Allowed
1F7A		Allowed
1F7C		Allowed
1F80	1FB4	Allowed
1FB6	1FBA	Allowed
1FBC		Allowed
1FC2	1FC4	Allowed
1FC6	1FC8	Allowed
1FCA		Allowed
1FCC		Allowed
1FD0	1FD2	Allowed
1FD6	1FDA	Allowed
1FE0	1FE2	Allowed
1FE4	1FEA	Allowed
1FEC		Allowed
1FF2	1FF4	Allowed
1FF6	1FF8	Allowed
1FFA		Allowed
1FFC		Allowed
200C	200D	Allowed
2010		Allowed
2019		Allowed
2027		Allowed
2D27		Allowed
2D2D		Allowed
2D80	2D96	Allowed
2DA0	2DA6	Allowed
2DA8	2DAE	Allowed
2DB0	2DB6	Allowed
2DB8	2DBE	Allowed
2DC0	2DC6	Allowed
2DC8	2DCE	Allowed
2DD0	2DD6	Allowed
2DD8	2DDE	Allowed
3005	3007	Allowed
3041	3096	Allowed
3099	309A	Allowed
309D	309E	Allowed
30A0	30FE	Allowed
3105	312D	Allowed
312F		Allowed
31A0	31BF	Allowed
3400	4DBF	Allowed
4E00	9FFF	Allowed
A67F		Allowed
A717	A71F	Allowed
A788		Allowed
A78D		Allowed
A792	A793	Allowed
A7AA		Allowed
A7AE		Allowed
A7B8	A7B9	Allowed
A7C0	A7CA	Allowed
A7D0	A7D1	Allowed
A7D3		Allowed
A7D5	A7D9	Allowed
A9E7	A9FE	Allowed
AA60	AA76	Allowed
AA7A	AA7F	Allowed
AB01	AB06	Allowed
AB09	AB0E	Allowed
AB11	AB16	Allowed
AB20	AB26	Allowed
AB28	AB2E	Allowed
AB66	AB67	Allowed
AC00	D7A3	Allowed
FA0E	FA0F	Allowed
FA11		Allowed
FA13	FA14	Allowed
FA1F		Allowed
FA21		Allowed
FA23	FA24	Allowed
FA27	FA29	Allowed
11301		Allowed
11303		Allowed
1133B	1133C	Allowed
16FF0	16FF1	Allowed
1B11F	1B122	Allowed
1B150	1B152	Allowed
1B164	1B167	Allowed
1DF00	1DF1E	Allowed
1E7E0	1E7E6	Allowed
1E7E8	1E7EB	Allowed
1E7ED	1E7EE	Allowed
1E7F0	1E7FE	Allowed
20000	2A6DF	Allowed
2A700	2B738	Allowed
2B740	2B81D	Allowed
2B820	2CEA1	Allowed
2CEB0	2EBE0	Allowed
30000	3134A	Allowed
END
